@@ -23,6 +23,7 @@ from collections import namedtuple
 from testflows._core.exceptions import exception
 from testflows._core.compress import CompressedFile
 from testflows._core.objects import Repeat, Retry
+from testflows._core.tracing import logging
 
 import testflows._core.contrib.rsa as rsa
 
@@ -203,4 +204,13 @@ def onoff(value):
         return NoneValue
     raise ArgumentTypeError(f"'{value}' is invalid")
 
-onoff.metavar = str(set(["yes", "1", "on", "no", "0", "off"])).replace(" ","").replace("'","")
\ No newline at end of file
+onoff.metavar = str(set(["yes", "1", "on", "no", "0", "off"])).replace(" ","").replace("'","")
+
+def trace_level(value):
+    if value.lower() in ["debug", "info", "warning", "error", "critical"]:
+        return getattr(logging, value.upper())
+    else:
+        raise ArgumentTypeError(f"'{value}' is invalid")
+
+trace_level.choices = ["debug", "info", "warning", "error", "critical"]
+trace_level.metavar = str(set(trace_level.choices)).replace(" ","").replace("'","")
\ No newline at end of file
